==> metpx_sarracenia-2.17.3a4-py3-none-any.whl: sarra/plugins/line_mode.py <==
#!/usr/bin/env python3

"""

  the default on_line handler for sr_poll. Verifies file are ok to download.
  uses parent.chmod setting as a mask to identify minimum permissions required to download file.

  means owner must have read permission...

sample line from sftp server:

  with following setting:

  chmod 400 

  this would be accepted:
  -rwxrwxr-x 1 1000 1000 8123 24 Mar 22:54 2017-03-25-0254-CL2D-AUTO-minute-swob.xml

  this would be rejected:
  --wxrwxr-x 1 1000 1000 8123 24 Mar 22:54 2017-03-25-0254-CL2D-AUTO-minute-swob.xml

"""


class Line_Mode(object): 

    def __init__(self,parent):
        if not hasattr(parent,'chmod'):
           parent.chmod = 0o4

        parent.logger.debug("line_mode initialized mask (from chmod setting) is: %03o " % parent.chmod )
          
    def modstr2num( self, m ):
        mode=0
        if ( m[0] == 'r' ) : mode += 4
        if ( m[1] == 'w' ) : mode += 2
        if ( m[2] == 'x' ) : mode += 1
        return mode

    def perform(self,parent):

        from stat import filemode

        ( modstr , links, uid, gid, size, dom, mona, t, name ) = parent.line.split()
    
        mode=0
        mode += self.modstr2num(modstr[1:4]) << 6
        mode += self.modstr2num(modstr[4:7]) << 3
        mode += self.modstr2num(modstr[7:10]) 
        
        #parent.logger.info("line_mode: %s mode: %03o" %  ( parent.line, mode ) )

        return ( ( mode & parent.chmod ) == parent.chmod ) 

line_mode = Line_Mode(self)

self.on_line = line_mode.perform

==> metpx_sarracenia-2.18.4b3-py3-none-any.whl: sarra/plugins/line_mode.py <==
#!/usr/bin/env python3

"""

  the default on_line handler for sr_poll. Verifies file are ok to download.
  uses parent.chmod setting as a mask to identify minimum permissions required to download file.

  means owner must have read permission...

sample line from sftp server:

  with following setting:

  chmod 400 

  this would be accepted:
  -rwxrwxr-x 1 1000 1000 8123 24 Mar 22:54 2017-03-25-0254-CL2D-AUTO-minute-swob.xml

  this would be rejected:
  --wxrwxr-x 1 1000 1000 8123 24 Mar 22:54 2017-03-25-0254-CL2D-AUTO-minute-swob.xml

"""


class Line_Mode(object): 

    def __init__(self,parent):
        if not hasattr(parent,'chmod'):
           parent.chmod = 0o4

        parent.logger.debug("line_mode initialized mask (from chmod setting) is: %03o " % parent.chmod )
          
    def modstr2num( self, m ):
        mode=0
        if ( m[0] == 'r' ) : mode += 4
        if ( m[1] == 'w' ) : mode += 2
        if ( m[2] == 'x' ) : mode += 1
        return mode

    def perform(self,parent):

        # filename with space is processed correctly

        parts = parent.line.split()

        name  = parts[-1]

        if not parent.ls_file_index in [-1,len(parts)-1] :
           name = ' '.join(parts[parent.ls_file_index:])

        ( modstr , links, uid, gid, size, dom, mona, t ) = parts[:8]
    
        mode=0
        mode += self.modstr2num(modstr[1:4]) << 6
        mode += self.modstr2num(modstr[4:7]) << 3
        mode += self.modstr2num(modstr[7:10]) 
        
        #parent.logger.info("line_mode: %s mode: %03o" %  ( parent.line, mode ) )

        return ( ( mode & parent.chmod ) == parent.chmod ) 

line_mode = Line_Mode(self)

self.on_line = line_mode.perform
